See the documentation at:
https://python-dpf.readthedocs.io/en/latest/index.html

If you use this package in your publication please cite our paper:

@article{brady2025pydpf,
      title={PyDPF: A Python Package for Differentiable Particle Filtering},
      author={John-Joseph Brady and Benjamin Cox and V\'{i}ctor Elvira and Yunpeng Li},
      year={2025},
      journal={arXiv preprint arXiv:2510.25693},
      url={https://arxiv.org/abs/2510.25693},
}